@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2003 Zope Corporation and Contributors.
+# Copyright (c) 2003 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,12 +13,12 @@
 ##############################################################################
 """Test XML configuration (ZCML) machinery.
 
-$Id: test_xmlconfig.py 106877 2009-12-22 15:11:04Z hannosch $
+$Id: test_xmlconfig.py 111665 2010-04-30 17:36:06Z hannosch $
 """
 import unittest
 import os
 import re
-from zope.testing.doctest import DocTestSuite, DocFileSuite
+from doctest import DocTestSuite, DocFileSuite
 from zope.testing import renormalizing
 from zope.configuration import xmlconfig, config
 from zope.configuration.tests.samplepackage import foo
